@@ -18,17 +18,15 @@
 #include "converterrunner.h"
 #include <QGuiApplication>
 #include <QClipboard>
+#include <QDesktopServices>
 #include <QSet>
 #include <QDebug>
 #include <KLocalizedString>
-#include <KToolInvocation>
 #include <KUnitConversion/Converter>
 #include <KUnitConversion/UnitCategory>
 
 #define CONVERSION_CHAR QLatin1Char( '>' )
 
-using namespace KUnitConversion;
-
 K_EXPORT_PLASMA_RUNNER(converterrunner, ConverterRunner)
 
 class StringParser
@@ -180,14 +178,13 @@ void ConverterRunner::match(Plasma::RunnerContext &context)
     }
     unit2 = cmd.rest();
 
-    Converter converter;
-    UnitCategory category = converter.categoryForUnit(unit1);
+    KUnitConversion::Converter converter;
+    KUnitConversion::UnitCategory category = converter.categoryForUnit(unit1);
     bool found = false;
-    if (category.id() == InvalidCategory) {
+    if (category.id() == KUnitConversion::InvalidCategory) {
         foreach (category, converter.categories()) {
             foreach (const QString& s, category.allUnits()) {
                 if (s.compare(unit1, Qt::CaseInsensitive) == 0) {
-                    unit1 = s;
                     found = true;
                     break;
                 }
@@ -201,16 +198,16 @@ void ConverterRunner::match(Plasma::RunnerContext &context)
         }
     }
 
-    QList<Unit> units;
+    QList<KUnitConversion::Unit> units;
 
     if (!unit2.isEmpty()) {
-        Unit u = category.unit(unit2);
+        KUnitConversion::Unit u = category.unit(unit2);
         if (!u.isNull() && u.isValid()) {
             units.append(u);
             config().writeEntry(category.name(), u.symbol());
         } else {
             const QStringList unitStrings = category.allUnits();
-            QList<Unit> matchingUnits;
+            QList<KUnitConversion::Unit> matchingUnits;
             foreach (const QString& s, unitStrings) {
                 if (s.startsWith(unit2, Qt::CaseInsensitive)) {
                     matchingUnits << category.unit(s);
@@ -223,18 +220,18 @@ void ConverterRunner::match(Plasma::RunnerContext &context)
         }
     } else {
         units = category.mostCommonUnits();
-        Unit u = category.unit(config().readEntry(category.name()));
+        KUnitConversion::Unit u = category.unit(config().readEntry(category.name()));
         if (!u.isNull() && units.indexOf(u) < 0) {
             units << u;
         }
     }
 
-    Unit u1 = category.unit(unit1);
-    foreach (const Unit& u, units) {
+    KUnitConversion::Unit u1 = category.unit(unit1);
+    foreach (const KUnitConversion::Unit& u, units) {
         if (u1 == u) {
             continue;
         }
-        Value v = category.convert(Value(value.toDouble(), u1), u);
+        KUnitConversion::Value v = category.convert(KUnitConversion::Value(value.toDouble(), u1), u);
         Plasma::QueryMatch match(this);
         match.setType(Plasma::QueryMatch::InformationalMatch);
         match.setIcon(QIcon::fromTheme(QLatin1String( "edit-copy" )));
@@ -249,7 +246,7 @@ void ConverterRunner::run(const Plasma::RunnerContext &context, const Plasma::Qu
     Q_UNUSED(context)
     const QString data = match.data().toString();
     if (data.startsWith(QLatin1String("http://"))) {
-        KToolInvocation::invokeBrowser(data);
+        QDesktopServices::openUrl(data);
     } else {
         QGuiApplication::clipboard()->setText(data);
     }
